@@ -1,20 +1,20 @@
 """
 Run all the core unit tests, not the lengthy and major integration tests
 """
-import unittest
 import sys
-sys.path.append('test')
+import unittest
+import rcwa
 
-import testCrystal as testCrystal
-import testHarmonics as testHarmonics
-import testLayer as testLayer
-import testMaterial as testMaterial
-import testMatrices1x1Harmonics as testMatrices1x1Harmonics
-import testMatrices3x3Harmonics as testMatrices3x3Harmonics
-import testNetlistParser as testNetlistParser
-import testSolver1x1Harmonics as testSolver1x1Harmonics
-import testSolver3x3Harmonics as testSolver3x3Harmonics
-import testSource as testSource
+import rcwa.test.test_crystal as testCrystal
+import rcwa.test.test_harmonics as testHarmonics
+import rcwa.test.test_layer as testLayer
+import rcwa.test.test_material as testMaterial
+import rcwa.test.test_matrices_1x1_harmonics as testMatrices1x1Harmonics
+import rcwa.test.test_matrices_3x3_harmonics as testMatrices3x3Harmonics
+import rcwa.test.test_netlist_parser as testNetlistParser
+import rcwa.test.test_solver_1x1_harmonics as testSolver1x1Harmonics
+import rcwa.test.test_solver_3x3_harmonics as testSolver3x3Harmonics
+import rcwa.test.test_source as testSource
 
 loader = unittest.TestLoader()
 suite = unittest.TestSuite()
